pylxd
~~~~~

.. image:: http://img.shields.io/pypi/v/pylxd.svg
    :target: https://pypi.python.org/pypi/pylxd
.. image:: https://travis-ci.org/lxc/pylxd.svg?branch=master
    :target: https://travis-ci.org/lxc/pylxd
.. image:: https://codecov.io/github/lxc/pylxd/coverage.svg?branch=master
    :target: https://codecov.io/github/lxc/pylxd
.. image:: https://readthedocs.org/projects/docs/badge/?version=latest
    :target: https://pylxd.readthedocs.io/en/latest/?badge=latest

A Python library for interacting with the LXD REST API.

Installation
=============
``pip install pylxd``

Bug reports
===========

Bug reports can be filed on the `GitHub repository
<https://github.com/lxc/pylxd/issues/new>`_.

Support and discussions
=======================

We use the `LXC mailing-lists for developer and user discussions
<https://lists.linuxcontainers.org>`_.

If you prefer live discussions, some of us also hang out in
`#lxcontainers
<http://webchat.freenode.net/?channels=#lxcontainers>`_ on irc.freenode.net.
